@@ -103,9 +103,11 @@ def run_pokemon():
 		for lab, ipheno in phenotype.iterrows():
 			out_fig_prefix = figures_dir + '/' + gene_name + '_' + lab  +'_' + pdb
 			ipheno = ipheno.to_frame(lab).T
-			cls = cluster(genotype,snps2aa,phenotype,distance_mat,pdb)
-			cls.plot(out_fig_prefix)
-			cls.plot_cluster(out_fig_prefix)
+			try:
+				cls = cluster(genotype,snps2aa,phenotype,distance_mat,pdb)
+				cls.plot(out_fig_prefix)
+				cls.plot_cluster(out_fig_prefix)
+			except: continue
 
 	# calculate kernel based on the score matrix
 	K = cal_Kernel(combined_w, genotype)
@@ -117,10 +119,14 @@ def run_pokemon():
 
 	for lab, ipheno in phenotype.iterrows():
 		temp = ipheno.values.astype(np.float64)
-		pval = obj.test(temp, acc=1e-8)	
-		record = [gene_name, pdb,lab, str(pval)]
-		outf.write('\t'.join(record) + '\n')
-	
+		try:
+			pval = obj.test(temp, acc=1e-8)	
+			record = [gene_name, pdb,lab, str(pval)]
+			outf.write('\t'.join(record) + '\n')
+		except: continue
+
 if __name__ == "__main__":
 	run_pokemon()
 
+
+
